# Generated by Django 2.0 on 2017-12-11 03:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('podcast', '0025_auto_20171211_0342'),
    ]

    operations = [
        migrations.AlterField(
            model_name='show',
            name='ttl',
            field=models.PositiveIntegerField(default=60, help_text='Time to live; minutes until cached feed refreshed', verbose_name='TTL'),
        ),
    ]



# Generated by Django 2.0 on 2017-12-11 03:42

from django.db import migrations


def get_ttl(apps, schema_editor):
    Show = apps.get_model('podcast', 'Show')
    for show in Show.objects.all():
        show.ttl = 60
        show.save(update_fields=['ttl'])


class Migration(migrations.Migration):

    dependencies = [
        ('podcast', '0024_show_ttl'),
    ]

    operations = [
        migrations.RunPython(get_ttl, reverse_code=migrations.RunPython.noop),
    ]



# Generated by Django 2.0 on 2017-12-11 04:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('podcast', '0026_auto_20171211_0342'),
    ]

    operations = [
        migrations.AddField(
            model_name='show',
            name='managing_editor',
            field=models.EmailField(default='', help_text='E-mail of administrative contact', max_length=255, verbose_name='editor e-mail'),
        ),
        migrations.AddField(
            model_name='show',
            name='webmaster',
            field=models.EmailField(blank=True, help_text='E-mail of technical contact; if blank, uses editor e-mail', max_length=255, verbose_name='webmaster e-mail'),
        ),
        migrations.AlterField(
            model_name='show',
            name='author_email',
            field=models.EmailField(blank=True, help_text='E-mail of administrative contact; if blank, uses editor e-mail', max_length=254, verbose_name='author e-mail'),
        ),
        migrations.AlterField(
            model_name='show',
            name='author_name',
            field=models.CharField(blank=True, help_text='Name of "artist" of the podcast; if blank, uses show title', max_length=255, verbose_name='author name'),
        ),
        migrations.AlterField(
            model_name='show',
            name='owner_email',
            field=models.EmailField(blank=True, help_text='E-mail of technical contact; if blank, uses webmaster e-mail', max_length=254, verbose_name='owner e-mail'),
        ),
        migrations.AlterField(
            model_name='show',
            name='owner_name',
            field=models.CharField(blank=True, help_text='Name of technical contact; if blank, uses show title', max_length=255, verbose_name='owner name'),
        ),
    ]



# Generated by Django 2.0 on 2017-12-11 04:24

from django.db import migrations


def get_managing_editor(apps, schema_editor):
    Show = apps.get_model('podcast', 'Show')
    for show in Show.objects.all():
        show.managing_editor = show.author_email
        show.webmaster = show.owner_email
        show.save(update_fields=['managing_editor', 'webmaster'])


class Migration(migrations.Migration):

    dependencies = [
        ('podcast', '0027_auto_20171211_0424'),
    ]

    operations = [
        migrations.RunPython(get_managing_editor, reverse_code=migrations.RunPython.noop),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-10-09 23:25
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('podcast', '0002_remove_episode_order'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='show',
            name='ttl',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.7 on 2017-11-21 21:25
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('podcast', '0021_auto_20171028_1742'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='category',
            name='json',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.7 on 2017-11-21 21:39
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('podcast', '0022_remove_category_json'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='show',
            name='itunes',
        ),
        migrations.AddField(
            model_name='show',
            name='apple',
            field=models.URLField(blank=True, help_text='Paste Apple Podcasts URL here after submission of show feed URL to <a href="https://podcastsconnect.apple.com/">Podcasts Connect</a>', verbose_name='Apple Podcasts URL'),
        ),
        migrations.AlterField(
            model_name='episode',
            name='block',
            field=models.BooleanField(default=False, help_text='Prevents episode from appearing on Apple Podcasts', verbose_name='block?'),
        ),
        migrations.AlterField(
            model_name='show',
            name='block',
            field=models.BooleanField(default=False, help_text='Prevents entire podcast from appearing on Apple Podcasts', verbose_name='block?'),
        ),
    ]



# Generated by Django 2.0 on 2017-12-11 04:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('podcast', '0028_auto_20171211_0424'),
    ]

    operations = [
        migrations.AlterField(
            model_name='show',
            name='managing_editor',
            field=models.EmailField(help_text='E-mail of administrative contact', max_length=255, verbose_name='editor e-mail'),
        ),
    ]
